@@ -1,5 +1,8 @@
 /*
  * Copyright (C) 2010 Pierre-Luc Beaudoin <pierre-luc@pierlux.com>
+ * Copyright (C) 2010 Collabora
+ * @author Pierre-Luc Beaudoin <pierre-luc@pierlux.com>
+ * @author Alban Crequy <alban.crequy@collabora.co.uk>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,10 +34,11 @@
 #include <gdk/gdkx.h>
 #include <X11/Xatom.h>
 #include <dbus/dbus-glib.h>
-#include <libosso-abook/osso-abook.h>
 
 #include <location/location-gps-device.h>
 #include <location/location-gpsd-control.h>
+#include <telepathy-glib/account.h>
+#include <telepathy-glib/contact.h>
 
 static void create_map_area (MapBuddyWindow *self);
 static void create_menu (MapBuddyWindow *self);
@@ -46,6 +50,7 @@ static void on_copy_link (GtkButton *button, MapBuddyWindow *self);
 static void on_about (GtkButton *button, MapBuddyWindow *self);
 static void on_locate_me (GtkButton *button, MapBuddyWindow *self);
 static void on_layer (GtkButton *button, MapBuddyWindow *self);
+static void on_show_contacts (GtkButton *button, MapBuddyWindow *self);
 static gboolean on_key_pressed (GtkWindow* window, GdkEventKey *event, MapBuddyWindow *self);
 static void on_state_changed (GObject *gobject, GParamSpec *pspec, MapBuddyWindow *self);
 static void on_zoom_level_changed (GObject *gobject, GParamSpec *pspec, MapBuddyWindow *self);
@@ -87,6 +92,12 @@ map_buddy_window_dispose (GObject *object)
       self->gps_device = NULL;
     }
 
+  if (self->map_buddy_contact_layer)
+    {
+      g_object_unref (self->map_buddy_contact_layer);
+      self->map_buddy_contact_layer = NULL;
+    }
+
   G_OBJECT_CLASS (map_buddy_window_parent_class)->dispose (object);
 }
 
@@ -115,7 +126,6 @@ on_window_realize (GtkWidget *widget,
   ungrab_volume_keys (self);
 }
 
-
 static void
 map_buddy_window_init (MapBuddyWindow *self)
 {
@@ -133,6 +143,9 @@ map_buddy_window_init (MapBuddyWindow *self)
   GtkWidget *main_vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (self), main_vbox);
 
+  /* Watch contacts location */
+  self->map_buddy_contact_layer = map_buddy_contact_layer_new ();
+
   /* Create all necessary parts: */
   create_map_area (self);
   create_menu (self);
@@ -207,6 +220,11 @@ create_map_area (MapBuddyWindow *self)
   champlain_view_add_layer (self->view, CHAMPLAIN_LAYER (self->layer));
   champlain_layer_show (self->layer);
 
+  /* Contact layer */
+  self->contact_layer = champlain_selection_layer_new ();
+  champlain_view_add_layer (self->view, CHAMPLAIN_LAYER (self->contact_layer));
+  map_buddy_contact_layer_start (self->map_buddy_contact_layer, self->contact_layer);
+
   self->merchant_layer = champlain_selection_layer_new ();
   champlain_view_add_layer (self->view, CHAMPLAIN_LAYER (self->merchant_layer));
   champlain_layer_show (self->merchant_layer);
@@ -488,6 +506,9 @@ create_menu (MapBuddyWindow *self)
   self->copy_item = add_menu_item (main_menu, _("Copy Map Link"),
       G_CALLBACK (on_copy_link), self);
 
+  self->show_contacts = add_menu_item (main_menu, _("Hide contacts"),
+      G_CALLBACK (on_show_contacts), self);
+
   add_menu_item (main_menu, _("Donate"),
       G_CALLBACK (open_url), "http://www.pierlux.com/map-buddy/donate/");
 
@@ -708,7 +729,6 @@ on_layer (GtkButton *button,
   else if (strcmp (selection, MAP_TERRAIN) == 0)
     id = CHAMPLAIN_MAP_SOURCE_MFF_RELIEF;
 
-  g_print ("sel: %s, id: %s\n", selection, id);
   self->current_layer = id;
   factory = champlain_map_source_factory_dup_default ();
   source = champlain_map_source_factory_create (factory, id);
@@ -719,6 +739,23 @@ on_layer (GtkButton *button,
   gtk_widget_hide (dialog);
 }
 
+static void
+on_show_contacts (GtkButton *button,
+                  MapBuddyWindow *self)
+{
+
+  if (CLUTTER_ACTOR_IS_VISIBLE (CLUTTER_ACTOR (self->contact_layer)))
+    {
+      champlain_layer_hide (self->contact_layer);
+      hildon_button_set_title (HILDON_BUTTON (button), _("Show contacts"));
+    }
+  else
+    {
+      champlain_layer_show (self->contact_layer);
+      hildon_button_set_title (HILDON_BUTTON (button), _("Hide contacts"));
+    }
+}
+
 static void
 on_state_changed (GObject *gobject,
                   GParamSpec *pspec,
@@ -1319,3 +1356,4 @@ map_buddy_window_show_details (MapBuddyWindow *self,
   gtk_widget_show_all (win);
   g_string_free (license, TRUE);
 }
+
