@@ -21,7 +21,9 @@
 
 #include "me-marker.h"
 #include "merchant.h"
+#include "contact-layer.h"
 
+#include <libosso-abook/osso-abook.h>
 #include <hildon/hildon.h>
 #include <champlain/champlain.h>
 #include <location/location-gps-device.h>
@@ -63,6 +65,7 @@ struct _MapBuddyWindow
 
   /* Menu */
   GtkWidget *copy_item;
+  GtkWidget *show_contacts;
 
   /* Toolbar */
   GtkWidget *toolbar;
@@ -75,6 +78,10 @@ struct _MapBuddyWindow
   GList *merchants;
   ChamplainLayer *merchant_layer;
 
+  /* Telepathy contacts */
+  MapBuddyContactLayer *map_buddy_contact_layer;
+  ChamplainLayer *contact_layer;
+
   GtkWidget* embed;
   ChamplainView *view;
   const gchar* current_layer; /* Current map source */
